# OIDCProxyHeaderMapping

The mapping between header name and value.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of the header that will be set. | [optional] 
**value** | **str** | The value of the header that will be set. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


